@@ -9,6 +9,7 @@ configFolder="/home/user/.SleepAnalyser/" #users home dir with ending /
 homedir="/home/user/"
 defaultRecordFolder="/home/user/MyDocs/SleepAnalyser/" #users record dir with ending /
 ConfigFile="SleepAnalyser.conf"
+PresetNamesFile="Presetnames.conf"
 
 developmentconfigFolder="/home/gruinelli/Entwicklung/Maemo/GARAGE_SVN/Sleepanalyser/" #development PC
 developmentRecordFolder="/home/gruinelli/Entwicklung/Maemo/GARAGE_SVN/Sleepanalyser/data/" #development PC
@@ -19,6 +20,8 @@ AccSensorPath="/sys/class/i2c-adapter/i2c-3/3-001d/coord"
 
 dateformat="%Y-%m-%d %H:%M:%S" #the date/time is stored in this format in the record files
 
+song_file_types="*.mp3 *.ogg *.wav"
+
 LogFile="/home/user/MyDocs/SleepAnalyser/SleepAnalyser.log" #Place for log file. IF YOU CHANGE THIS PATH, YOU ALSO HAVE TO CHANGE IT IN /usr/bin/sleepanalyser!
 
 translation_copyrights="English, German: George Ruinelli\n"+\
@@ -60,6 +63,7 @@ Ysize=121 #default value Y scale in px
 
 
 
+
 DelayStartTime=0
 Yscale_Movement=0 #Y stretching of yellow movement bars
 Yscale_Sleep_Pattern=0  #Y stretching of blue sleep pattern
@@ -103,6 +107,7 @@ LastWindow=""
 
 user=""
 app_path="./"
+preset_names=["", "", "", ""]
 
 last_beep=0
 
@@ -190,5 +195,5 @@ AlternativeAlarm=""
 cliStart=""
 cliStop=""
 
-CurrentVolume=0
+CurrentVolume=5 #start value for wake up music
 WakeUp_Song_Volume_Increase_Step=4 #increase step time in pro mille (0.1%)
