@@ -200,10 +200,7 @@ def StopRecordFile():
 ###########################################################################
 def LoadFileList():
     print "Load list of all csv files in folder:", data.RecordFolder
-    output = os.popen("cd "+str(data.RecordFolder)+"; ls -C1 *.csv").read() # run ls and make the output look like a file I can read
-    #Note: Above command could also be implemented with os.listdir(). This might give a minor speed improvement
-    data.arrRecordFiles=output.split("\n")
-    data.arrRecordFiles.pop()
+    data.arrRecordFiles=getFileList(data.RecordFolder,  "*.csv")
     if(data.debug==True): print data.arrRecordFiles
     if(data.RecordFilename>""):
         if(data.debug==True): print data.RecordFilename
