@@ -37,6 +37,74 @@ _ = i18n.language.ugettext
 
 
 
+
+###########################################################################
+## Function:    LoadConfig
+## Description: This function loads the preset names from the preset names file
+##                If the parameter is missing in the file, it uses the default value
+## Parameters:  none
+## Returns:     none
+###########################################################################
+def LoadPresetNames():
+    global PresetNames
+    print "Load preset names"
+    
+    PresetNames = ConfigParser.SafeConfigParser()
+    try:
+        PresetNames.read(data.configFolder+data.PresetNamesFile)
+    except: #use default PresetNames
+        print "PresetNames file "+data.configFolder+data.PresetNamesFile + " not existing or not compatible"
+
+    try:
+        PresetNames.add_section('main')
+    except:
+        pass
+
+    for i in range(0, 4):
+        try:
+            tmp=PresetNames.get('main', 'preset'+str(i+1))
+            data.preset_names[i] = tmp.decode("utf-8")
+        except:
+            data.preset_names[i]=str(_("Preset")+" "+str(i+1))
+            PresetNames.set('main', 'preset'+str(i+1), data.preset_names[i])
+            
+    print data.preset_names
+
+
+
+
+###########################################################################
+## Function:    WritePresetNames
+## Description: This function loads the preset names into the preset names file
+## Parameters:  none
+## Returns:     none
+###########################################################################
+def WritePresetNames():
+    global PresetNames
+    print "Write preset names"
+ 
+    for i in range(0, 3):
+        PresetNames.set('main', 'Preset'+str(i+1),  str(data.preset_names[i].encode( "utf-8" )))
+ 
+ 
+    f=data.configFolder+data.PresetNamesFile
+    if(data.debug==True): print "Save preset names ("+f+")"
+    if (not os.path.exists(str(data.configFolder))):
+        print "Create configuration folder: ", data.configFolder
+        os.mkdir(data.configFolder)
+    try:
+        handle = open(f, 'w')
+        PresetNames.write(handle)
+        handle.close()
+        print "Preset names saved"
+    except:
+        print "Failed to write preset names file!"
+        
+        
+
+
+
+
 ###########################################################################
 ## Function:    LoadConfig
 ## Description: This function loads the data from the config file
@@ -323,9 +391,9 @@ def WriteConfig():
         print "Create configuration folder: ", data.configFolder
         os.mkdir(data.configFolder)
     try:
-        data.configfile = open(f, 'w')
-        config.write(data.configfile)
-        data.configfile.close()
+        handle = open(f, 'w')
+        config.write(handle)
+        handle.close()
         print "Configuration saved"
     except:
         print "Failed to write configuration file!"
@@ -578,6 +646,23 @@ def Notify(notify_txt):
 
 
 
+###########################################################################
+## Function:    getFileList
+## Description: Returns an array with a file list in a given directory
+## Parameters:  directory, file filter
+## Returns:     array with files
+###########################################################################
+def getFileList(path,  filter):
+    output = os.popen("cd \""+str(path)+"\"; ls -C1 "+str(filter)).read() # run ls and make the output look like a file I can read
+    #Note: Above command could also be implemented with os.listdir(). This might give a minor speed improvement
+    arr=output.split("\n")
+    arr.pop()   
+    return arr
+
+
+
+
+
 ###########################################################################
 ## Function:    PlaySong
 ## Description: Sets the requested volume and opens the media player with the requested song
@@ -622,7 +707,13 @@ def GetSongLength(filename):
     output = os.popen("ffmpeg -i \""+str(filename)+"\" 2>&1 | grep Duration").read() # run ffmpeg and make the output look like a file I can read
     arr=output.split(".")
     arr=arr[0].split(":")
-    duration=int(int(arr[1])*3600+int(arr[2])*60+int(arr[3]))
+
+#TODO: Figure out why ffmeg not can return duration on some files
+    try:
+        duration=int(int(arr[1])*3600+int(arr[2])*60+int(arr[3]))
+    except:
+        duration=300 #set to 5 minutes
+        print "ERROR: Could not get song length!"
     return duration
 
 
