@@ -64,8 +64,8 @@ def ErrorReportDialog(trace,txt_email=None):
     arr=txt.split("\n")
 #    print arr
 #    txt="Please inform the author with an email (george@ruinelli.ch) and attach the log file "+data.LogFile+"\n[...]"
-    txt=""
-    for i in range(len(arr)-5, len(arr)-1): txt=txt+arr[i]+"\n"
+    txt="SleepAnalyser crashed and has to be closed.\n\nError:\n"
+    for i in range(len(arr)-7, len(arr)-1): txt=txt+arr[i]+"\n"
 
     QMessageBox.critical(None, "Oops! Error in SleepAnalyser "+data.version+"-"+data.build, txt, QMessageBox.Ok) #Max 11 lines in dialog!
 #    r=QInputDialog.getText(None, "Add Note", trace, QLineEdit.Normal, "---\nlll\nkkk")
